function varargout = TMP006gui(varargin)
% TMP006GUI M-file for TMP006gui.fig
%      TMP006GUI, by itself, creates a new TMP006GUI or raises the existing
%      singleton*.
%
%      H = TMP006GUI returns the handle to a new TMP006GUI or the handle to
%      the existing singleton*.
%
%      TMP006GUI('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in TMP006GUI.M with the given input arguments.
%
%      TMP006GUI('Property','Value',...) creates a new TMP006GUI or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before TMP006gui_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to TMP006gui_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help TMP006gui

% Last Modified by GUIDE v2.5 18-Aug-2009 18:44:17

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @TMP006gui_OpeningFcn, ...
                   'gui_OutputFcn',  @TMP006gui_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before TMP006gui is made visible.
function TMP006gui_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to TMP006gui (see VARARGIN)

% Choose default command line output for TMP006gui
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes TMP006gui wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = TMP006gui_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;



function initialvalue_Callback(hObject, eventdata, handles)
% hObject    handle to initialvalue (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of initialvalue as text
%        str2double(get(hObject,'String')) returns contents of initialvalue as a double


% --- Executes during object creation, after setting all properties.
function initialvalue_CreateFcn(hObject, eventdata, handles)
% hObject    handle to initialvalue (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function volatility_Callback(hObject, eventdata, handles)
% hObject    handle to volatility (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of volatility as text
%        str2double(get(hObject,'String')) returns contents of volatility as a double


% --- Executes during object creation, after setting all properties.
function volatility_CreateFcn(hObject, eventdata, handles)
% hObject    handle to volatility (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function drift_Callback(hObject, eventdata, handles)
% hObject    handle to drift (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of drift as text
%        str2double(get(hObject,'String')) returns contents of drift as a double


% --- Executes during object creation, after setting all properties.
function drift_CreateFcn(hObject, eventdata, handles)
% hObject    handle to drift (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function numdt_Callback(hObject, eventdata, handles)
% hObject    handle to numdt (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of numdt as text
%        str2double(get(hObject,'String')) returns contents of numdt as a double


% --- Executes during object creation, after setting all properties.
function numdt_CreateFcn(hObject, eventdata, handles)
% hObject    handle to numdt (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function steps_Callback(hObject, eventdata, handles)
% hObject    handle to steps (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of steps as text
%        str2double(get(hObject,'String')) returns contents of steps as a double


% --- Executes during object creation, after setting all properties.
function steps_CreateFcn(hObject, eventdata, handles)
% hObject    handle to steps (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end



function dendt_Callback(hObject, eventdata, handles)
% hObject    handle to dendt (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of dendt as text
%        str2double(get(hObject,'String')) returns contents of dendt as a double


% --- Executes during object creation, after setting all properties.
function dendt_CreateFcn(hObject, eventdata, handles)
% hObject    handle to dendt (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in generate.
function generate_Callback(hObject, eventdata, handles)
% hObject    handle to generate (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
set(handles.status,'String','Generating...');
drawnow;
val1 = str2num(get(handles.initialvalue,'String'));
val2 = str2num(get(handles.drift,'String'));
val3 = str2num(get(handles.volatility,'String'));
val4 = str2num(get(handles.numdt,'String')) / str2num(get(handles.dendt,'String'));
val5 = str2num(get(handles.steps,'String'));
S = StochasticGen(val1,val2,val3/100,val4,val5);

if (get(handles.dump,'Value') == 1)
    dates = num2str(datevec(now));
    
    csvwrite(['TMP006_dump.csv'],S);
end

figure
plot(S);
set(handles.status,'String','Done!');


% --- Executes on button press in dump.
function dump_Callback(hObject, eventdata, handles)
% hObject    handle to dump (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of dump


